local L = Capitalist.Locale
local realm = GetRealmName()
local character = UnitName("player")

local idEnchantingVellum = 38682

local componentsMemory = { }

function Capitalist:ComponentMemoryReset()
	componentsMemory = { }
end

function Capitalist:IsComponent(componentName)
	if (self.db.profile.components and
		self.db.profile.components[componentName]) then

		return true
	end

	return false
end

function Capitalist:GetComponentId(componentName)
	if (componentName == L["Enchanting Vellum"]) then
		return idEnchantingVellum
	else
		return self.db.profile.components[componentName].id
	end
end

function Capitalist:ComponentGetMerchant(componentName)
	return self.db.profile.components[componentName].merchant
end

function Capitalist:ComponentSetMerchant(componentName, merchant)
	self.db.profile.components[componentName].merchant = merchant
end

function Capitalist:OutputComponent(prefix, itemName, count)
	self:Print(self:StringForItem(prefix, self:GetComponentText(itemName), count).." @ "..self:PrettyCurrency(self:GetComponentCost(itemName) * 10000).." ea.")
end

function Capitalist:OutputMissingCosts()
	local rawComponents = {}
	for componentName, componentData in pairs(componentsMemory) do
		table.insert(rawComponents, componentName)
	end

	local outputtedHeader

	local i = 1
	while (i <= #rawComponents) do
		local componentName = rawComponents[i]

		local componentSkillName, componentProfession = self:SkillNameFromProductName(componentName)
		if (componentSkillName and componentProfession) then
			for subComponentName, subComponentCount in pairs(self.db.profile.professions[componentProfession][componentSkillName].components) do
				if (not tContains(rawComponents, subComponentName)) then
					table.insert(rawComponents, subComponentName)
				end
			end
		else
			if (not self.db.profile.components[componentName].cost) then
				if (not outputtedHeader) then
					self:Print(L["Components missing cost information:"])
					outputtedHeader = true
				end
				self:Print(string.format("  "..self:GetComponentText(componentName)))
			end
		end

		i = i + 1
	end

	if (not outputtedHeader) then
		self:Print(L["All component costs set."])
	end
end

function Capitalist:GetComponentText(itemName)
	if (self.db.profile.components and
		self.db.profile.components[itemName] and
		self.db.profile.components[itemName].link) then

		return self.db.profile.components[itemName].link
	end
	
	return itemName
end

function Capitalist:ComponentIsVisible(componentName)
	return componentsMemory[componentName] ~= nil
end

function Capitalist:ComponentSetVisible(componentName, visible)
	if (visible) then
		componentsMemory[componentName] = { }
	else
		componentsMemory[componentName] = nil
	end
end

function Capitalist:GetVisibleComponents()
	componentList = {}
	for componentName, componentData in pairs(componentsMemory) do
		table.insert(componentList, componentName)
	end
	return componentList
end

function Capitalist:StringForItem(prefix, item, count)
	local s = item;
	if (prefix) then
		s = prefix..s
	end
	if (count and (count > 1)) then
		s = s.." ["..count.."]"
	end
	return s
end
