local L = Capitalist.Locale
local realm = GetRealmName()
local character = UnitName("player")

local costsMemory = { }

function Capitalist:CostMemoryReset()
	costsMemory = { }
end

function Capitalist:GetComponentCost(componentName)
	if (self.db.profile.components and
		self.db.profile.components[componentName] and
		self.db.profile.components[componentName].cost) then
		return self.db.profile.components[componentName].cost
	else
		return self.componentPriceDefault
	end
end

function Capitalist:SetComponentCost(componentName, cost)
	self.db.profile.components[componentName].cost = cost
end

--REVIEW: Remove or formalize statistics information
--local hit = 0
--local miss = 0
function Capitalist:CalculateSkillCost(profession, skillName)
	local cost = costsMemory[skillName]

	if (not cost) then
		--miss = miss + 1
		cost = 0

		for componentName, componentCount in pairs(self.db.profile.professions[profession][skillName].components) do
			local componentCostInCopper

			local componentSkillName, componentProfession = self:SkillNameFromProductName(componentName)
			if (componentSkillName and componentProfession) then
				componentCostInCopper = self:CalculateSkillCost(componentProfession, componentSkillName)
			else
				componentCostInCopper = self:GetComponentCost(componentName) * 10000
			end

			cost = cost + componentCount * componentCostInCopper
		end

		costsMemory[skillName] = cost
	else
		--hit = hit + 1
	end

	return cost
end

function Capitalist:OutputItemCost(itemName)
	local skills = self:SkillsFromProductName(itemName)
	if (skills) then
		for skillName, profession in pairs(skills) do
			local itemText = self:ProductTextFromSkillName(profession, skillName)
			local itemCost = self:CalculateSkillCost(profession, skillName)	
			local recipeText = self:SkillTextFromSkillName(profession, skillName)
			self:Print(string.format(L["Product %s costs %s to make via %s."], itemText, self:PrettyCurrency(itemCost), recipeText))
		end
	elseif (self.db.profile.components[itemName]) then
		local itemText = self:GetComponentText(itemName)
		local itemCost = self:GetComponentCost(itemName) * 10000
		local itemMerchant = self:ComponentGetMerchant(itemName)
		if (itemMerchant) then
			self:Print(string.format(L["Component %s cost is set at %s, sold by %s."], itemText, self:PrettyCurrency(itemCost), itemMerchant))
		else
			self:Print(string.format(L["Component %s cost is set at %s."], itemText, self:PrettyCurrency(itemCost)))
		end
	else
		self:Print(string.format(L["Item %s value unknown."], itemName))
	end
end
